@@ -133,7 +133,7 @@ sub new {
         ops        => $opts->{ops}->get_ops_map,
         ips        => [],
         newips     => [],
-        handprint  => 'JQBF98', # the official handprint
+        handprint  => 'JQBF', # the official handprint
         _wrapping  => $wrapping,
       };
     bless $self, $class;
@@ -202,38 +202,40 @@ BEGIN {
 
 
 #
-# move_ip( $ip [,regex] )
+# move_ip( $ip )
 #
-# Move $ip according to its delta on the storage.
-#
-# If a regex ( a C<qr//> object ) is specified, then $ip will move as
-# long as the pointed character match the supplied regex.
-#
-# Example: given the code C<;foobar;> (assuming the IP points on the
-# first C<;>) and the regex C<qr/[^;]/>, the IP will move in order to
-# point on the C<r>.
+# Move $ip according to its delta on the storage. Spaces and comments
+# (enclosed with semi-colons ';') are skipped silently.
 #
 sub move_ip {
-    my ($self, $ip, $re) = @_;
-    my $storage = $self->storage;
+    my ($self, $ip) = @_;
 
-    if ( defined $re ) {
-        my $orig = $ip->get_position;
-        # moving as long as we did not reach the condition.
-        while ( $storage->get_char($ip->get_position) =~ $re ) {
-            $self->_move_ip_forward($ip);
-            $self->abort("infinite loop")
-                if $ip->get_position == $orig;
+    my $storage = $self->storage;
+    my $orig = $ip->get_position;
+    $self->_move_ip_once($ip);
+    my $char;
+    MOVE: while (1) {
+        # sanity check
+        my $pos = $ip->get_position;
+        $char = $storage->get_char($pos);
+
+        # skip spaces
+        if ( $char eq ' ' ) {
+            $self->_move_ip_till( $ip, qr/ / );   # skip all spaces
+            $self->_move_ip_once($ip);            # skip last space
+            redo MOVE;
         }
 
-        # we moved one char too far.
-        $ip->dir_reverse;
-        $self->_move_ip_forward($ip);
-        $ip->dir_reverse;
+        # skip comments
+        if ( $char eq ';' ) {
+            $self->_move_ip_once($ip);             # skip comment ';'
+            $self->_move_ip_till( $ip, qr/[^;]/ ); # till just before matching ';'
+            $self->_move_ip_once($ip);             # till matching ';'
+            $self->_move_ip_once($ip);             # till just after matching ';'
+            redo MOVE;
+        }
 
-    } else {
-        # moving one step beyond...
-        $self->_move_ip_forward($ip);
+        last MOVE;
     }
 }
 
@@ -412,7 +414,7 @@ sub process_ip {
         } elsif ( $char eq ' ' ) {
             # A serie of spaces, to be treated as one space.
             $self->debug( "string-mode: pushing char ' '\n" );
-            $self->move_ip( $ip, qr/ / );
+            $self->_move_ip_till( $ip, qr/ / );
             $ip->spush( $ord );
 
         } else {
@@ -422,38 +424,53 @@ sub process_ip {
         }
 
     } else {
-        # Not in string-mode.
-        if ( exists $self->get_ops->{$char} ) {
-            # Regular instruction.
-            my $meth = $self->get_ops->{$char};
-            $meth->($self);
-
-        } else {
-            # Not a regular instruction: reflect.
-            $self->debug( "the command value $ord (char='$char') is not implemented.\n");
-            $ip->dir_reverse;
-        }
+        $self->_do_instruction($char);
     }
 
     if ($continue) {
         # Tick done for this IP, let's move it and push it in the
         # set of non-terminated IPs.
-        $self->move_ip( $self->get_curip );
+        if ( $ip->get_string_mode ) {
+            $self->_move_ip_once( $self->get_curip );
+        } else {
+            $self->move_ip( $self->get_curip );
+        }
         push @{ $self->get_newips }, $ip unless $ip->get_end;
     }
 }
 
 #-- PRIVATE METHODS
 
+#
+# $lbi->_do_instruction( $char );
+#
+# interpret instruction $char according to loaded ops map.
+#
+sub _do_instruction {
+    my ($self, $char) = @_;
+
+    if ( exists $self->get_ops->{$char} ) {
+        # regular instruction.
+        my $meth = $self->get_ops->{$char};
+        $meth->($self, $char);
+
+    } else {
+        # not a regular instruction: reflect.
+        my $ord = ord($char);
+        $self->debug( "the command value $ord (char='$char') is not implemented.\n");
+        $self->get_curip->dir_reverse;
+    }
+}
+
 
 #
-# $lbi->_move_ip_forward( $ip );
+# $lbi->_move_ip_once( $ip );
 #
 # move $ip one step further, according to its velocity. if $ip gets out
 # of bounds, then a wrapping is performed (according to current
 # interpreter wrapping implementation) on the ip.
 #
-sub _move_ip_forward {
+sub _move_ip_once {
     my ($self, $ip) = @_;
     my $storage = $self->storage;
 
@@ -474,6 +491,35 @@ sub _move_ip_forward {
 }
 
 
+#
+# _move_ip_till( $ip,regex )
+#
+# Move $ip according to its delta on the storage,  as long as the pointed
+# character match the supplied regex (a qr// object).
+#
+# Example: given the code C<;foobar;> (assuming the IP points on the
+# first C<;>) and the regex C<qr/[^;]/>, the IP will move in order to
+# point on the C<r>.
+#
+sub _move_ip_till {
+    my ($self, $ip, $re) = @_;
+    my $storage = $self->storage;
+
+    my $orig = $ip->get_position;
+    # moving as long as we did not reach the condition.
+    while ( $storage->get_char($ip->get_position) =~ $re ) {
+        $self->_move_ip_once($ip);
+        $self->abort("infinite loop")
+        if $ip->get_position == $orig;
+    }
+
+    # we moved one char too far.
+    $ip->dir_reverse;
+    $self->_move_ip_once($ip);
+    $ip->dir_reverse;
+}
+
+
 1;
 __END__
 
